import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from "react";
import "./date-picker-calendar.css";
import "./monkey-patch-calendar-day";
import "./monkey-patch-day-picker";
import { ArgumentError, mergeClasses } from "../../shared";
import { ArrowIcon } from "../../icons";
import { NAVIGATION_ROLE } from "./element-roles";
import { PureComponent, cloneElement } from "react";
import { bool, func, node, number, oneOfType, string } from "prop-types";
import { isFunction, isNil } from "lodash";
import { momentObj as momentType } from "react-moment-proptypes";
import moment from "moment";
const PHRASES = {
  chooseAvailableStartDate: ({
    date
  }) => "Choose ".concat(date, "."),
  chooseAvailableEndDate: ({
    date
  }) => "Choose ".concat(date, ".")
};
export class DatePickerCalendar extends PureComponent {
  constructor(...args) {
    super(...args);

    this.isDayBlocked = day => {
      const {
        minDate,
        maxDate
      } = this.props;

      if (!isNil(minDate) && !isNil(maxDate)) {
        return day.isBefore(minDate, "day") || day.isAfter(maxDate, "day");
      }

      if (!isNil(minDate)) {
        return day.isBefore(minDate, "day");
      }

      if (!isNil(maxDate)) {
        return day.isAfter(maxDate, "day");
      }

      return false;
    };

    this.isMonthBlocked = month => {
      const {
        minDate,
        maxDate
      } = this.props;

      if (!isNil(minDate) || !isNil(maxDate)) {
        const firstDay = moment(month).startOf("month");
        const lastDay = moment(month).endOf("month");
        return this.isDayBlocked(firstDay) && this.isDayBlocked(lastDay);
      }

      return false;
    };

    this.getInitialVisibleMonth = () => {
      const {
        initialDate,
        initialVisibleMonth,
        numberOfMonths
      } = this.props;

      if (!isNil(initialVisibleMonth)) {
        if (isFunction(initialVisibleMonth)) {
          return initialVisibleMonth(this.props);
        }

        return initialVisibleMonth;
      } else if (numberOfMonths > 1) {
        return this.getInitialVisibleMonthFromDates();
      }

      return initialDate;
    };
  }

  componentDidMount() {
    const {
      minDate,
      maxDate
    } = this.props;

    if (!isNil(minDate) && !isNil(maxDate)) {
      if (minDate.isSameOrAfter(maxDate)) {
        throw new ArgumentError("DatePicker - \"minDate\" must be before \"maxDate\".");
      }
    }
  }

  getInitialVisibleMonthFromDates() {
    const {
      initialDate
    } = this.props;
    const initialMonth = initialDate;
    const nextMonth = moment(initialMonth).add(1, "months");

    if (this.isMonthBlocked(nextMonth)) {
      // When the next month is blocked, show the previous and current months instead of the current and next months.
      const previousMonth = moment(initialMonth).subtract(1, "months");

      if (!this.isMonthBlocked(previousMonth)) {
        return previousMonth;
      }
    }

    return initialMonth;
  } // Temporary fix until the following PR is merged: https://github.com/airbnb/react-dates/pull/1672


  getNavigationRestrictionProps() {
    const {
      minDate,
      maxDate,
      temporarySingleDatePickerFlag
    } = this.props;

    if (!temporarySingleDatePickerFlag) {
      return {
        minDate,
        maxDate
      };
    }

    return {};
  }

  renderNavPrev() {
    return /*#__PURE__*/React.createElement("div", {
      tabIndex: "0",
      className: "flex",
      "data-role": NAVIGATION_ROLE
    }, /*#__PURE__*/React.createElement(ArrowIcon, {
      size: "large",
      className: "rotate-180 fill-marine-500"
    }));
  }

  renderNavNext() {
    return /*#__PURE__*/React.createElement("div", {
      tabIndex: "0",
      className: "flex",
      "data-role": NAVIGATION_ROLE
    }, /*#__PURE__*/React.createElement(ArrowIcon, {
      size: "large",
      className: "fill-marine-500"
    }));
  }

  renderCalendar() {
    const {
      calendar,
      minDate,
      maxDate,
      numberOfMonths
    } = this.props;
    return cloneElement(calendar, _objectSpread({}, this.getNavigationRestrictionProps(), {
      navPrev: this.renderNavPrev(),
      navNext: this.renderNavNext(),
      isDayBlocked: !isNil(minDate) || !isNil(maxDate) ? this.isDayBlocked : undefined,
      initialVisibleMonth: this.getInitialVisibleMonth,
      numberOfMonths: numberOfMonths,
      phrases: PHRASES,
      transitionDuration: 0,
      noBorder: true,
      keepOpenOnDateSelect: true,
      hideKeyboardShortcutsPanel: true
    }));
  }

  render() {
    const {
      buttons,
      leftContent,
      className
    } = this.props;
    const classes = mergeClasses("o-ui calendar flex z-2", className);
    return /*#__PURE__*/React.createElement("div", {
      className: classes
    }, leftContent, /*#__PURE__*/React.createElement("div", {
      className: "flex flex-column"
    }, this.renderCalendar(), buttons));
  }

}
DatePickerCalendar.displayName = "DatePickerCalendar";
DatePickerCalendar.propTypes = {
  calendar: node.isRequired,
  buttons: node.isRequired,
  leftContent: node,
  minDate: momentType,
  maxDate: momentType,
  initialDate: momentType.isRequired,
  initialVisibleMonth: oneOfType([momentType, func]),
  numberOfMonths: number,
  className: string,
  temporarySingleDatePickerFlag: bool
};
DatePickerCalendar.defaultProps = {
  temporarySingleDatePickerFlag: false
};