import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from "react";
import { ArgumentError, LARGE, MEDIUM, MINI, SMALL, TINY, mergeClasses, throwWhenUnsupportedPropIsProvided } from "../../shared";
import { Dropdown } from "../../dropdown";
import { Label } from "semantic-ui-react";
import { MonkeyPatchSemanticDropdown } from "./monkey-patch-semantic-dropdown";
import { SelectItem, createSelectItem, renderAvatar, renderIcons } from "./item";
import { any, arrayOf, bool, element, func, object, oneOf, oneOfType, shape, string } from "prop-types";
import { forwardRef } from "react";
import { isArray, isNil } from "lodash"; // Sizes constants are duplicated here until https://github.com/reactjs/react-docgen/pull/352 is merged. Otherwise it will not render properly in the docs.

const SIZES = ["small", "medium", "large"];
const DEFAULT_SIZE = "medium";
const UNSUPPORTED_PROPS = ["basic", "button", "compact", "additionLabel", "additionPosition", "allowAdditions", "direction", "floating", "header", "item", "labeled", "openOnFocus", "pointing", "selection", "selectOnBlur", "selectOnNavigation", "simple"];
const SIZES_TO_LABEL = {
  [SMALL]: MINI,
  [MEDIUM]: TINY,
  [LARGE]: SMALL
};
const ACTION_SHAPE = {
  content: element,
  className: string
};
const propTypes = {
  /**
   * An array of items object shorthands.
   */
  options: arrayOf(any),

  /**
   * A select can have a list of actions after his items.
   */
  actions: arrayOf(shape(ACTION_SHAPE)),

  /**
   * A select can vary in size.
   */
  size: oneOf(SIZES),

  /**
   * @ignore
   */
  inline: bool,

  /**
   * @ignore
   */
  multiple: bool,

  /**
   * @ignore
   */
  forwardedRef: oneOfType([object, func])
};
const defaultProps = {
  size: DEFAULT_SIZE,
  inline: false,
  multiple: false
};

function throwWhenMutuallyExclusivePropsAreProvided({
  inline,
  size
}) {
  if (inline && size !== DEFAULT_SIZE) {
    throw new ArgumentError("@orbit-ui/react-components/select you cannot specify a size for an inline select.");
  }
}

function throwWhenMultipleAndValuesIsNotAnArray({
  multiple,
  defaultValue,
  value
}) {
  if (multiple) {
    if (!isNil(defaultValue) && !isArray(defaultValue)) {
      throw new ArgumentError("@orbit-ui/react-components/select defaultValues must be an array when multiple is true.");
    }

    if (!isNil(value) && !isArray(value)) {
      throw new ArgumentError("@orbit-ui/react-components/select values must be an array when multiple is true.");
    }
  }
}

export function PureSelect(props) {
  const {
    options,
    actions,
    inline,
    size,
    forwardedRef
  } = props,
        rest = _objectWithoutProperties(props, ["options", "actions", "inline", "size", "forwardedRef"]);

  throwWhenUnsupportedPropIsProvided(props, UNSUPPORTED_PROPS, "@orbit-ui/react-components/select");
  throwWhenMutuallyExclusivePropsAreProvided(props);
  throwWhenMultipleAndValuesIsNotAnArray(props);

  const renderLabel = ({
    text,
    avatar,
    icons,
    iconsPosition
  }, index, otherProps) => {
    let content = text;

    if (!isNil(avatar)) {
      content = /*#__PURE__*/React.createElement(React.Fragment, null, renderAvatar(avatar), text);
    } else if (!isNil(icons)) {
      let left = null;
      let right = null;

      if (iconsPosition === "right") {
        right = renderIcons(icons, size);
      } else {
        left = renderIcons(icons, size);
      }

      content = /*#__PURE__*/React.createElement(React.Fragment, null, !isNil(left) && left, /*#__PURE__*/React.createElement("span", {
        className: "mr1"
      }, text), !isNil(right) && right);
    }

    return /*#__PURE__*/React.createElement(Label, Object.assign({
      content: content,
      size: SIZES_TO_LABEL[size]
    }, otherProps));
  };

  const renderAction = (_ref, index) => {
    let {
      content,
      key,
      className
    } = _ref,
        otherProps = _objectWithoutProperties(_ref, ["content", "key", "className"]);

    const classes = mergeClasses(className, "action bg-white o-100");
    return _objectSpread({
      content,
      className: classes,
      disabled: true,
      key: key || index
    }, otherProps);
  };

  const renderOptions = () => {
    const selectOptions = options.map(x => {
      return _objectSpread({}, x, {
        factory: createSelectItem
      });
    });

    if (!isNil(actions)) {
      return [...selectOptions, ...actions.map(renderAction)];
    }

    return selectOptions;
  };

  return /*#__PURE__*/React.createElement(Dropdown, Object.assign({
    options: renderOptions(),
    selectOnBlur: false,
    selectOnNavigation: false,
    selection: !inline,
    inline: inline,
    size: size,
    renderLabel: renderLabel,
    ref: forwardedRef,
    __semanticDropdown: MonkeyPatchSemanticDropdown
  }, rest));
}
PureSelect.displayName = "PureSelect";
PureSelect.propTypes = propTypes;
PureSelect.defaultProps = defaultProps;
export const Select = forwardRef((props, ref) => /*#__PURE__*/React.createElement(PureSelect, Object.assign({}, props, {
  forwardedRef: ref
})));
[PureSelect, Select].forEach(x => {
  x.Item = SelectItem;
});